@@ -32,8 +32,8 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include <yara/utils.h>
 
-#define YR_MAJOR_VERSION   3
-#define YR_MINOR_VERSION   7
+#define YR_MAJOR_VERSION   4
+#define YR_MINOR_VERSION   0
 #define YR_MICRO_VERSION   1
 
 #define version_str(s) _version_str(s)
@@ -55,33 +55,24 @@ typedef enum _YR_CONFIG_NAME
 {
   YR_CONFIG_STACK_SIZE,
   YR_CONFIG_MAX_STRINGS_PER_RULE,
-  YR_CONFIG_MAX
+  YR_CONFIG_MAX_MATCH_DATA,
+
+  YR_CONFIG_LAST  // End-of-enum marker, not a configuration
 
 } YR_CONFIG_NAME;
 
 
 #define DEFAULT_STACK_SIZE              16384
 #define DEFAULT_MAX_STRINGS_PER_RULE    10000
+#define DEFAULT_MAX_MATCH_DATA          512
 
 
 YR_API int yr_initialize(void);
 
-
 YR_API int yr_finalize(void);
 
-
-YR_API void yr_finalize_thread(void);
-
-
-YR_API int yr_get_tidx(void);
-
-
-YR_API void yr_set_tidx(int);
-
-
 YR_API int yr_set_configuration(YR_CONFIG_NAME, void*);
 
-
 YR_API int yr_get_configuration(YR_CONFIG_NAME, void*);
 
 
